==> mahara-15.04.0_1.txz: usr/local/www/mahara/lang/en.utf8/pieforms.php <==
<?php
/**
 *
 * @package    mahara
 * @subpackage lang
 * @author     Catalyst IT Ltd
 * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL version 3 or later
 * @copyright  For copyright information on Mahara, please see the README file distributed with this software.
 *
 */

defined('INTERNAL') || die();

$string['element.bytes.bytes'] = 'Bytes';
$string['element.bytes.kilobytes'] = 'Kilobytes';
$string['element.bytes.megabytes'] = 'Megabytes';
$string['element.bytes.gigabytes'] = 'Gigabytes';
$string['element.bytes.invalidvalue'] = 'Value must be a number';

$string['element.calendar.invalidvalue'] = 'Invalid date/time specified';
$string['element.calendar.opendatepicker'] = 'Open date picker';

$string['element.date.monthnames'] = 'January,February,March,April,May,June,July,August,September,October,November,December';
$string['element.date.specify'] = 'Set date';
$string['element.date.at'] = 'at';

$string['element.expiry.days'] = 'Days';
$string['element.expiry.weeks'] = 'Weeks';
$string['element.expiry.months'] = 'Months';
$string['element.expiry.years'] = 'Years';
$string['element.expiry.noenddate'] = 'No end date';

$string['element.files.addattachment'] = 'Add attachment';

$string['element.select.other'] = 'Other';

$string['element.color.transparent'] = 'Transparent or ';

$string['rule.before.before'] = 'This cannot be after the field "%s"';

$string['rule.email.email'] = 'Email address is invalid';

$string['rule.integer.integer'] = 'The field must be an integer';

$string['rule.maxlength.maxlength'] = 'This field must be at most %d characters long.';

$string['rule.minlength.minlength'] = 'This field must be at least %d characters long.';

$string['rule.minvalue.minvalue'] = 'This value cannot be smaller than %d.';

$string['rule.regex.regex'] = 'This field is not in valid form.';

$string['rule.required.required'] = 'This field is required.';

$string['rule.validateoptions.validateoptions'] = 'The option "%s" is invalid.';

$string['rule.maxvalue.maxvalue'] = 'This value cannot be larger than %d.';

==> mahara-16.04.3.txz: usr/local/www/mahara/lang/en.utf8/pieforms.php <==
<?php
/**
 *
 * @package    mahara
 * @subpackage lang
 * @author     Catalyst IT Ltd
 * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL version 3 or later
 * @copyright  For copyright information on Mahara, please see the README file distributed with this software.
 *
 */

defined('INTERNAL') || die();

$string['element.bytes.bytes'] = 'Bytes';
$string['element.bytes.kilobytes'] = 'Kilobytes';
$string['element.bytes.megabytes'] = 'Megabytes';
$string['element.bytes.gigabytes'] = 'Gigabytes';
$string['element.bytes.invalidvalue'] = 'Value must be a number';

$string['element.calendar.invalidvalue'] = 'Invalid date/time specified';
$string['element.calendar.opendatepicker'] = 'Open date picker';
$string['element.calendar.format.help.dayofmonth1digit'] = 'D';
$string['element.calendar.format.help.dayofmonth2digits'] = 'DD';
$string['element.calendar.format.help.month2digit'] = 'MM';
$string['element.calendar.format.help.year2digit'] = 'YY';
$string['element.calendar.format.help.year4digit'] = 'YYYY';
$string['element.calendar.format.help.24hour1digit'] = 'H';
$string['element.calendar.format.help.24hour2digits'] = 'HH';
$string['element.calendar.format.help.12hour1digit'] = 'H';
$string['element.calendar.format.help.12hour2digits'] = 'HH';
$string['element.calendar.format.help.minute2digits'] = 'MM';
$string['element.calendar.format.help.second2digits'] = 'SS';
$string['element.calendar.format.help.ampmlowercase'] = 'am';
$string['element.calendar.format.help.ampmuppercase'] = 'AM';


$string['element.date.monthnames'] = 'January,February,March,April,May,June,July,August,September,October,November,December';
$string['element.date.specify'] = 'Set date';
$string['element.date.at'] = 'at';

$string['element.expiry.days'] = 'Days';
$string['element.expiry.weeks'] = 'Weeks';
$string['element.expiry.months'] = 'Months';
$string['element.expiry.years'] = 'Years';
$string['element.expiry.noenddate'] = 'No end date';

$string['element.files.addattachment'] = 'Add attachment';

$string['element.select.other'] = 'Other';
$string['element.select.remove'] = 'Remove "%s"';

$string['element.color.transparent'] = 'Default or ';

$string['rule.before.before'] = 'This cannot be after the field "%s"';

$string['rule.email.email'] = 'Email address is invalid';

$string['rule.integer.integer'] = 'The field must be an integer';

$string['rule.maxlength.maxlength'] = 'This field must be at most %d characters long.';

$string['rule.minlength.minlength'] = 'This field must be at least %d characters long.';

$string['rule.minvalue.minvalue'] = 'This value cannot be smaller than %d.';

$string['rule.regex.regex'] = 'This field is not in valid form.';

$string['rule.required.required'] = 'This field is required.';

$string['rule.validateoptions.validateoptions'] = 'The option "%s" is invalid.';

$string['rule.maxvalue.maxvalue'] = 'This value cannot be larger than %d.';

$string['switchbox.true'] = 'True';
$string['switchbox.false'] = 'False';
$string['switchbox.on'] = 'On';
$string['switchbox.off'] = 'Off';
$string['switchbox.yes'] = 'Yes';
$string['switchbox.no'] = 'No';
